==> qgis_3.0.0.orig.tar.xz: qgis-3.0.0/src/providers/db2/qgsdb2provider.h <==
/***************************************************************************
  qgsdb2provider.h - Data provider for DB2 server
  --------------------------------------
  Date      : 2016-01-27
  Copyright : (C) 2016 by David Adler
                          Shirley Xiao, David Nguyen
  Email     : dadler at adtechgeospatial.com
              xshirley2012 at yahoo.com, davidng0123 at gmail.com
****************************************************************************
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 ***************************************************************************/

#ifndef QGSDB2PROVIDER_H
#define QGSDB2PROVIDER_H

#include "qgsvectordataprovider.h"
#include "qgsvectorlayerexporter.h"
#include "qgscoordinatereferencesystem.h"
#include "qgsgeometry.h"
#include "qgsfields.h"
#include <QtSql>

/**
 * \class QgsDb2Provider
 * \brief Data provider for DB2 server.
 */
class QgsDb2Provider : public QgsVectorDataProvider
{
    Q_OBJECT

  public:
    explicit QgsDb2Provider( const QString &uri = QString() );

    ~QgsDb2Provider() override;

    /**
     * Returns a QSqlDatabase object that can connect to DB2 for LUW or z/OS.
     *
     * If service is provided, then username and password is required.
     * If service is not provided, the remaining arguments are required.
     *
     * \param connInfo A string containing all connection information.
     */
    static QSqlDatabase getDatabase( const QString &connInfo, QString &errMsg );

    static bool openDatabase( QSqlDatabase db );

    QgsAbstractFeatureSource *featureSource() const override;

    QgsFeatureIterator getFeatures( const QgsFeatureRequest &request = QgsFeatureRequest() ) const override;

    QgsWkbTypes::Type wkbType() const override;

    long featureCount() const override;

    /**
     * Update the extent for this layer.
     */
    void updateStatistics() const;


    QgsFields fields() const override;

    QgsCoordinateReferenceSystem crs() const override;
    QgsRectangle extent() const override;
    bool isValid() const override;
    QString subsetString() const override;

    bool setSubsetString( const QString &theSQL, bool updateFeatureCount = true ) override;

    bool supportsSubsetString() const override { return true; }

    QString name() const override;

    QString description() const override;

    QgsAttributeList pkAttributeIndexes() const override;

    QgsVectorDataProvider::Capabilities capabilities() const override;

    bool addFeatures( QgsFeatureList &flist, QgsFeatureSink::Flags flags = nullptr ) override;

    bool deleteFeatures( const QgsFeatureIds &id ) override;

    bool changeAttributeValues( const QgsChangedAttributesMap &attr_map ) override;

    bool changeGeometryValues( const QgsGeometryMap &geometry_map ) override;

    //! Import a vector layer into the database
    static QgsVectorLayerExporter::ExportError createEmptyLayer(
      const QString &uri,
      const QgsFields &fields,
      QgsWkbTypes::Type wkbType,
      const QgsCoordinateReferenceSystem &srs,
      bool overwrite,
      QMap<int, int> *oldToNewAttrIdxMap,
      QString *errorMessage = nullptr,
      const QMap<QString, QVariant> *options = nullptr
    );

    //! Convert a QgsField to work with DB2
    static bool convertField( QgsField &field );

    //! Convert a QgsField to work with DB2
    static QString qgsFieldToDb2Field( const QgsField &field );

  protected:
    //! Loads fields from input file to member attributeFields
    QVariant::Type decodeSqlType( int typeId );
    void loadMetadata();
    void loadFields();

  private:
    static void db2WkbTypeAndDimension( QgsWkbTypes::Type wkbType, QString &geometryType, int &dim );
    static QString db2TypeName( int typeId );

    QgsFields mAttributeFields; //fields
    QMap<int, QVariant> mDefaultValues;
    mutable QgsRectangle mExtent; //layer extent
    bool mValid;
    bool mUseEstimatedMetadata;
    bool mSkipFailures;
    long mNumberFeatures = 0;
    int mFidColIdx = -1;
    QString mFidColName;
    QString mExtents;
    mutable long mSRId;
    mutable int  mEnvironment;
    mutable QString mSrsName;
    mutable QString mGeometryColName, mGeometryColType;
    QString mLastError; //string containing the last reported error message
    mutable QgsCoordinateReferenceSystem mCrs; //coordinate reference system
    QgsWkbTypes::Type mWkbType = QgsWkbTypes::Unknown;
    QSqlQuery mQuery; //current SQL query
    QString mConnInfo; // full connection information
    QString mSchemaName, mTableName; //current layer schema/name
    QString mSqlWhereClause; //SQL statement used to limit the features retrieved
    QSqlDatabase mDatabase; //the database object
    static int sConnectionId;

    //sets the error messages
    void setLastError( const QString &error )
    {
      mLastError = error;
    }

    friend class QgsDb2FeatureSource;
};

#endif

==> qgis_3.10.14+dfsg.orig.tar.xz: qgis-3.10.14/src/providers/db2/qgsdb2provider.h <==
/***************************************************************************
  qgsdb2provider.h - Data provider for DB2 server
  --------------------------------------
  Date      : 2016-01-27
  Copyright : (C) 2016 by David Adler
                          Shirley Xiao, David Nguyen
  Email     : dadler at adtechgeospatial.com
              xshirley2012 at yahoo.com,  davidng0123 at gmail.com
****************************************************************************
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 ***************************************************************************/

#ifndef QGSDB2PROVIDER_H
#define QGSDB2PROVIDER_H

#include "qgsvectordataprovider.h"
#include "qgsvectorlayerexporter.h"
#include "qgscoordinatereferencesystem.h"
#include "qgsgeometry.h"
#include "qgsfields.h"
#include <QtSql>
#include <QMutex>

#include "qgsprovidermetadata.h"

/**
 * \class QgsDb2Provider
 * \brief Data provider for DB2 server.
 */
class QgsDb2Provider : public QgsVectorDataProvider
{
    Q_OBJECT

  public:

    static const QString DB2_PROVIDER_KEY;
    static const QString DB2_PROVIDER_DESCRIPTION;

    explicit QgsDb2Provider( const QString &uri, const QgsDataProvider::ProviderOptions &providerOptions );

    ~QgsDb2Provider() override;

    /**
     * Returns a QSqlDatabase object that can connect to DB2 for LUW or z/OS.
     *
     * If service is provided, then username and password is required.
     * If service is not provided, the remaining arguments are required.
     *
     * \param connInfo A string containing all connection information.
     */
    static QSqlDatabase getDatabase( const QString &connInfo, QString &errMsg );

    static bool openDatabase( QSqlDatabase db );

    QgsAbstractFeatureSource *featureSource() const override;

    QgsFeatureIterator getFeatures( const QgsFeatureRequest &request = QgsFeatureRequest() ) const override;

    QgsWkbTypes::Type wkbType() const override;

    long featureCount() const override;

    /**
     * Update the extent for this layer.
     */
    void updateStatistics() const;


    QgsFields fields() const override;

    QgsCoordinateReferenceSystem crs() const override;
    QgsRectangle extent() const override;
    bool isValid() const override;
    QString subsetString() const override;

    bool setSubsetString( const QString &theSQL, bool updateFeatureCount = true ) override;

    bool supportsSubsetString() const override { return true; }

    QString name() const override;

    QString description() const override;

    QgsAttributeList pkAttributeIndexes() const override;

    QgsVectorDataProvider::Capabilities capabilities() const override;

    bool addFeatures( QgsFeatureList &flist, QgsFeatureSink::Flags flags = nullptr ) override;

    bool deleteFeatures( const QgsFeatureIds &id ) override;

    bool changeAttributeValues( const QgsChangedAttributesMap &attr_map ) override;

    bool changeGeometryValues( const QgsGeometryMap &geometry_map ) override;

    //! Import a vector layer into the database
    static QgsVectorLayerExporter::ExportError createEmptyLayer(
      const QString &uri,
      const QgsFields &fields,
      QgsWkbTypes::Type wkbType,
      const QgsCoordinateReferenceSystem &srs,
      bool overwrite,
      QMap<int, int> *oldToNewAttrIdxMap,
      QString *errorMessage = nullptr
    );

    //! Convert a QgsField to work with DB2
    static bool convertField( QgsField &field );

    //! Convert a QgsField to work with DB2
    static QString qgsFieldToDb2Field( const QgsField &field );

  protected:
    //! Loads fields from input file to member attributeFields
    QVariant::Type decodeSqlType( int typeId );
    void loadMetadata();
    void loadFields();

  private:
    static void db2WkbTypeAndDimension( QgsWkbTypes::Type wkbType, QString &geometryType, int &dim );
    static QString db2TypeName( int typeId );

    /**
       * Returns a thread-safe connection name for use with QSqlDatabase
       */
    static QString dbConnectionName( const QString &name );

    static QMutex sMutex;

    QgsFields mAttributeFields; //fields
    QMap<int, QVariant> mDefaultValues;
    mutable QgsRectangle mExtent; //layer extent
    bool mValid;
    bool mUseEstimatedMetadata;
    bool mSkipFailures;
    long mNumberFeatures = 0;
    int mFidColIdx = -1;
    QString mFidColName;
    QString mExtents;
    mutable long mSRId;
    mutable int  mEnvironment;
    mutable QString mSrsName;
    mutable QString mGeometryColName, mGeometryColType;
    QString mLastError; //string containing the last reported error message
    mutable QgsCoordinateReferenceSystem mCrs; //coordinate reference system
    QgsWkbTypes::Type mWkbType = QgsWkbTypes::Unknown;
    QSqlQuery mQuery; //current SQL query
    QString mConnInfo; // full connection information
    QString mSchemaName, mTableName; //current layer schema/name
    QString mSqlWhereClause; //SQL statement used to limit the features retrieved
    QSqlDatabase mDatabase; //the database object
    static int sConnectionId;

    //sets the error messages
    void setLastError( const QString &error )
    {
      mLastError = error;
    }

    friend class QgsDb2FeatureSource;
};

class QgsDb2ProviderMetadata: public QgsProviderMetadata
{
  public:
    QgsDb2ProviderMetadata();
    QList<QgsDataItemProvider *> dataItemProviders() const override;
    QgsVectorLayerExporter::ExportError createEmptyLayer(
      const QString &uri,
      const QgsFields &fields,
      QgsWkbTypes::Type wkbType,
      const QgsCoordinateReferenceSystem &srs,
      bool overwrite,
      QMap<int, int> &oldToNewAttrIdxMap,
      QString &errorMessage,
      const QMap<QString, QVariant> *options ) override;
    QgsDb2Provider *createProvider( const QString &uri, const QgsDataProvider::ProviderOptions &options ) override;
};

#endif
